package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!`````"$```````!``````````)@!`0``
M`````````$``.``)`$``&@`9``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````&";````````8)L`````````
M``$```````$````&````>/L```````!X^P$``````'C[`0``````$`4`````
M```X!0```````````0```````@````8```"(^P```````(C[`0``````B/L!
M```````0`@```````!`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````R),```````#(DP```````,B3````````!`$````````$`0````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````'C[````````>/L!``````!X^P$`
M`````(@$````````B`0````````!`````````"]L:6(O;&0M;&EN=7@M86%R
M8V@V-"YS;RXQ```$````%`````,```!'3E4`L$QYX!04R$X;:D@NAP$#.A`C
MO90$````$`````$```!'3E4```````,````'`````````!$```!(````!```
M``@````A$!``!<`$A"@"$`6`AD"$@@D`!`D@!(B(@!!!N@`""$@```!)````
M3````%````!1````60```%H```!;`````````%T```!>````7P```&````!A
M````9````````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[;49-1\=E0\E"'_
MY`[9<5@<XD?&`;(!BV^L2^/`0OK7A\+E/RQ8[Y=YNN.2?/NA;&!K"4/69Z_,
M9D)%U>R)!W#3,V+;[16,)<P-.I<+?ZF<F^"G`@IJ&IY0O]I7&Z/@^TD`````
M`````````````````````````````````P`+`,`:````````````````````
M`````P`6`````@````````````````"3`@``$@``````````````````````
M``#E````$@````````````````````````#Z`0``$@``````````````````
M``````!Z`@``$@````````````````````````"Q````$@``````````````
M``````````"3`0``$@`````````````````````````V`@``$@``````````
M```````````````!````(``````````````````````````Z`0``$@``````
M``````````````````!W`0``$@````````````````````````"<`P``$@``
M``````````````````````#%`@``$@````````````````````````#:`@``
M$0````````````````````````#J`0``$@````````````````````````!^
M`0``$@````````````````````````!#`0``$@``````````````````````
M``!O`0``$@````````````````````````#.`@``$@``````````````````
M``````"A`0``$@````````````````````````#&````$@``````````````
M``````````!8````(@`````````````````````````0````(```````````
M``````````````"P`0``$@````````````````````````"K`@``$@``````
M```````````````````L````(`````````````````````````#L````$@``
M``````````````````````":````$@````````````````````````"C````
M$@````````````````````````"J````$@````````````````````````#.
M`0``$0````````````````````````!G````$@``````````````````````
M``"=`@``$@````````````````````````#[````%@``````````````````
M```````.`0``$@````````````````````````!)`@``$@``````````````
M``````````#U````$@`````````````````````````I`0``$@``````````
M``````````````"V`@``$@````````````````````````"I`0``$@``````
M``````````````````"]`0``$@````````````````````````!M````$@``
M``````````````````````"Y````$@````````````````````````#5`0``
M$@````````````````````````!8`0``$@````````````````````````!_
M````$@````````````````````````"%`@``$@``````````````````````
M``!S`@``$@`````````````````````````;`@``$@``````````````````
M``````"B````$@````````````````````````":`0``$@``````````````
M``````````"^````$@````````````````````````",`0``$@``````````
M```````````````&`@``$@````````````````````````"%`0``$@``````
M``````````````````!G`@``$@````````````````````````"W`0``$@``
M``````````````````````!1`0``$@````````````````````````!:`@``
M$0````````````````````````"8`@``$@`````````````````````````>
M`0``$@`````````````````````````G`@``$@``````````````````````
M``!G`0``$@````````````````````````!&````$@``````````````````
M``````"0````$0````````````````````````#C`0``$@``````````````
M``````````#0````$@````````````````````````#7````$@``````````
M``````````````"2````$0````````````````````````#3`@``$@``````
M``````````````````#W`P``$``7`+```@````````````````"E`P``$@`-
M`#!.````````\``````````<!```$@`-`!!&````````!`8```````!3````
M$@`-`,`>````````#`(````````<`P``$@`-`+0[````````!``````````Z
M`P``$@`-`!1,````````&`(```````#-`P``$``7`(@``@``````````````
M``!"!```$@`-`,`[````````+`(````````"!```$``7`(@``@``````````
M```````M`P``$@`-`/`]````````+`````````!0`P``$@`-`%1$````````
M<`````````"Q`P``$0`/`%!2````````!`````````#;`P``$@`-`&!/````
M````"`$```````#F`P``$@`-`*0Z````````+`````````#N`P``$``7`+``
M`@`````````````````7!```$``7`+```@`````````````````P!```$@`-
M`.1$````````+`$```````#``P``$``6`````@````````````````!T`P``
M$@`-`"`^````````:`$````````I!```$``6`(@``@````````````````!/
M!```$0`6`(```@``````"`````````#&`P``$@`-```A````````-```````
M```.!```$@`-`"!/````````0`````````#"`P``(``6`````@``````````
M``````"*`P``$@`-`,1$````````(`````````!>`P``$@`-`-`Z````````
MY`````````"``P``$@`-`'!0````````P`$```````#V`P``$``7`+```@``
M``````````````!9!```$@`-`)`_````````Q`0`````````7U]G;6]N7W-T
M87)T7U\`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T
M97)434-L;VYE5&%B;&4`7U]L:6)C7W-T87)T7VUA:6X`7U]C>&%?9FEN86QI
M>F4`86)O<G0`7U]R96=I<W1E<E]A=&9O<FL`7U]S=&%C:U]C:&M?9F%I;`!?
M7V5N=FER;VX`<W1R;F-M<`!L<W1A=#8T`&%C8V5S<P!L<V5E:S8T`')E860`
M;W!E;F1I<@!R96%D9&ER-C0`<W1R;&5N`%]?<W!R:6YT9E]C:&L`=6YL:6YK
M`&-L;W-E9&ER`')M9&ER`%!,7V-U<G)E;G1?8V]N=&5X=`!B;V]T7T1Y;F%,
M;V%D97(`4&5R;%]N97=84P!097)L7VYE=UA37V9L86=S`')E861L:6YK`%!E
M<FQ?<W9?<V5T<'8`;65M8VAR`%!E<FQ?<W9?<V5T<'9N`&UE;6UO=F4`<F5A
M;&QO8P!G971P:60`;65M8W!Y`'-T<F-H<@!S=')D=7``<W1R=&]K`'-T<F-M
M<`!S=')R8VAR`&=E='5I9`!S=')S='(`;6MD:7(`7U]E<G)N;U]L;V-A=&EO
M;@!S=&1E<G(`7U]F<')I;G1F7V-H:P!O<&5N-C0`4&5R;%]G=E]F971C:'!V
M`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?;6=?<V5T
M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7V%T9F]R
M:U]L;V-K`%!,7V1O7W5N9'5M<`!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]P
M87)S90!P97)L7V1E<W1R=6-T`'!E<FQ?9G)E90!097)L7W-Y<U]T97)M`'!E
M<FQ?86QL;V,`<&5R;%]C;VYS=')U8W0`<&5R;%]R=6X`97AI=`!M96US970`
M7U]S=&%C:U]C:&M?9W5A<F0`;&EB<&5R;"YS;RXU+C,V`&QI8F,N<V\N-@!L
M9"UL:6YU>"UA87)C:#8T+G-O+C$`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S
M96YA;64`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R
M7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G971?
M=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?24]?<W1D:6Y?
M=7-E9`!?7V1A=&%?<W1A<G0`7U]B<W-?<W1A<G1?7P!S:&%?=7!D871E`'AS
M7VEN:70`7U]E;F1?7P!?7V)S<U]E;F1?7P!?7V)S<U]S=&%R=`!S:&%?:6YI
M=`!?96YD`'!A<E]M:W1M<&1I<@!?961A=&$`<&%R7W-E='5P7VQI8G!A=&@`
M<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P87)?:6YI=%]E;G8`1TQ)0D-?,BXQ
M-P!'3$E"0U\R+C,T`$=,24)#7S(N,S,```````````$``@`!``$``@`"``$`
M`0`"``(``@`!``,``0`"``$``@`"``(``@`"``$``@`!``$``@`"``0``@`"
M``(``0`!``$``0`"``$``0`"``(``@`"``(``0`"``$``@`!``0``@`"``(`
M`0`"``$``@`"``$``@`!``$``@`%``(``@`"``(``@`"``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`````````!``$`!@,``!`````@````EY&6!@```P!F!`````````$``P#\
M`@``$`````````"TD98&```%`'$$```0````LY&6!@``!`!\!```$````)>1
ME@8```(`9@0```````!X^P$```````,$````````$"(```````"`^P$`````
M``,$````````P"$```````"8_P$```````,$````````%$P```````#H_P$`
M``````,$````````@``"``````#X_P$```````,$````````P!X````````(
M``(```````,$````````"``"```````@``(```````,$````````<),`````
M```H``(```````,$````````P%(````````X``(```````,$````````L%,`
M``````!```(```````,$````````4),```````!(``(```````,$````````
M6),```````!0``(```````,$````````8),```````!8``(```````,$````
M````:),```````!H``(```````,$````````.),```````!P``(```````,$
M````````0),```````"```(```````,$````````R%4```````"(_P$`````
M``$$```)``````````````"0_P$```````$$```*``````````````"@_P$`
M``````$$```/``````````````"H_P$```````$$```7``````````````"P
M_P$```````$$```8``````````````"X_P$```````$$```;````````````
M``#`_P$```````$$```@``````````````#(_P$```````8$```C````````
M``````#0_P$```````$$```D``````````````#8_P$```````$$```E````
M``````````#@_P$```````$$```\``````````````#P_P$```````$$``!&
M``````````````"P_0$```````($```#``````````````"X_0$```````($
M```$``````````````#`_0$```````($```%``````````````#(_0$`````
M``($```&``````````````#0_0$```````($```'``````````````#8_0$`
M``````($```(``````````````#@_0$```````($```*``````````````#H
M_0$```````($```+``````````````#P_0$```````($```,````````````
M``#X_0$```````($```-````````````````_@$```````($```.````````
M```````(_@$```````($```0```````````````0_@$```````($```1````
M```````````8_@$```````($```2```````````````@_@$```````($```3
M```````````````H_@$```````($```4```````````````P_@$```````($
M```5```````````````X_@$```````($```6``````````````!`_@$`````
M``($```7``````````````!(_@$```````($```9``````````````!0_@$`
M``````($```:``````````````!8_@$```````($```<``````````````!@
M_@$```````($```=``````````````!H_@$```````($```>````````````
M``!P_@$```````($```?``````````````!X_@$```````($```A````````
M``````"`_@$```````($```B``````````````"(_@$```````($```F````
M``````````"0_@$```````($```G``````````````"8_@$```````($```H
M``````````````"@_@$```````($```I``````````````"H_@$```````($
M```J``````````````"P_@$```````($```K``````````````"X_@$`````
M``($```L``````````````#`_@$```````($```M``````````````#(_@$`
M``````($```N``````````````#0_@$```````($```O``````````````#8
M_@$```````($```P``````````````#@_@$```````($```Q````````````
M``#H_@$```````($```R``````````````#P_@$```````($```S````````
M``````#X_@$```````($```T````````````````_P$```````($```U````
M```````````(_P$```````($```V```````````````0_P$```````($```W
M```````````````8_P$```````($```X```````````````@_P$```````($
M```Y```````````````H_P$```````($```Z```````````````P_P$`````
M``($```[```````````````X_P$```````($```]``````````````!`_P$`
M``````($```^``````````````!(_P$```````($```_``````````````!0
M_P$```````($``!```````````````!8_P$```````($``!!````````````
M``!@_P$```````($``!#``````````````!H_P$```````($``!$````````
M``````!P_P$```````($``!%``````````````!X_P$```````($``!'````
M```````````?(`/5_7N_J?T#`)&:`0"4_7O!J,`#7]8``````````/![OZGP
M``#0$=9&^1"B-I$@`A_6'R`#U1\@`]4?(`/5\```T!':1OD0PC:1(`(?UO``
M`-`1WD;Y$.(VD2`"'];P``#0$>)&^1`"-Y$@`A_6\```T!'F1OD0(C>1(`(?
MUO```-`1ZD;Y$$(WD2`"'];P``#0$>Y&^1!B-Y$@`A_6\```T!'R1OD0@C>1
M(`(?UO```-`1]D;Y$*(WD2`"'];P``#0$?I&^1#"-Y$@`A_6\```T!'^1OD0
MXC>1(`(?UO```-`1`D?Y$`(XD2`"'];P``#0$09'^1`B.)$@`A_6\```T!$*
M1_D00CB1(`(?UO```-`1#D?Y$&(XD2`"'];P``#0$1)'^1"".)$@`A_6\```
MT!$61_D0HCB1(`(?UO```-`1&D?Y$,(XD2`"'];P``#0$1Y'^1#B.)$@`A_6
M\```T!$B1_D0`CF1(`(?UO```-`1)D?Y$"(YD2`"'];P``#0$2I'^1!".9$@
M`A_6\```T!$N1_D08CF1(`(?UO```-`1,D?Y$((YD2`"'];P``#0$39'^1"B
M.9$@`A_6\```T!$Z1_D0PCF1(`(?UO```-`1/D?Y$.(YD2`"'];P``#0$4)'
M^1`".I$@`A_6\```T!%&1_D0(CJ1(`(?UO```-`12D?Y$$(ZD2`"'];P``#0
M$4Y'^1!B.I$@`A_6\```T!%21_D0@CJ1(`(?UO```-`15D?Y$*(ZD2`"'];P
M``#0$5I'^1#".I$@`A_6\```T!%>1_D0XCJ1(`(?UO```-`18D?Y$`([D2`"
M'];P``#0$69'^1`B.Y$@`A_6\```T!%J1_D00CN1(`(?UO```-`1;D?Y$&([
MD2`"'];P``#0$7)'^1"".Y$@`A_6\```T!%V1_D0HCN1(`(?UO```-`1>D?Y
M$,([D2`"'];P``#0$7Y'^1#B.Y$@`A_6\```T!&"1_D0`CR1(`(?UO```-`1
MAD?Y$"(\D2`"'];P``#0$8I'^1!"/)$@`A_6\```T!&.1_D08CR1(`(?UO``
M`-`1DD?Y$((\D2`"'];P``#0$99'^1"B/)$@`A_6\```T!&:1_D0PCR1(`(?
MUO```-`1GD?Y$.(\D2`"'];P``#0$:)'^1`"/9$@`A_6\```T!&F1_D0(CV1
M(`(?UO```-`1JD?Y$$(]D2`"'];P``#0$:Y'^1!B/9$@`A_6\```T!&R1_D0
M@CV1(`(?UO```-`1MD?Y$*(]D2`"'];P``#0$;I'^1#"/9$@`A_6\```T!&^
M1_D0XCV1(`(?U@``````````````````````````````````````````_7NZ
MJ>,``-!CT$?Y_0,`D?-3`:GU6P*IXH<#J>+C`)'A`P&1X$\`N>`S`9%D`$#Y
MY"\`^00`@-+.__^7X@``T$+$1_G@``#0`.Q'^>$#`JK(#`"4X```T`#P1_D`
M`$`Y0`D`-.```-``Y$?Y0=`[U?,``/`B:&#X]$]`N4$H4CF`$@`1E`X`$2$$
M`#)!*!(Y`'Q]DZ/__Y?C`P"JYB-`^6)"`I'@``#0`/1'^2$``)#'`$#Y(>`6
MD00`0/D@``"0Y4]`N0``%Y%G!`"I0P0`^60``:F_!`!Q#0D`5"$`@-(@#``1
MQ'AA^"$$`)%DV"#XOP`!:VS__U2E#``1=4("D7_8)?CB`Q0J`0``T`0`@-(A
M0!R1H`Y`^=;^_Y?T`P`JP`0`-'5"`I'V4P&1H`Y`^5C__Y<@``"0X0,6J@``
M#9&X!`"4(`0`M'-"`I%@#D#YO/[_ER/__Y?@``"P`-!'^>(O0/D!`$#Y0@`!
MZP$`@-+!!`!4]5M"J>`#%"KS4T&I_7O&J,`#7];^_O^7\P``T&)"`I%`#`#Y
M0`,`M!W__Y?@``"P`.1'^4'0.]4B:&#X7]PH.;#__Q>@#D#YR?[_E_0#`"K8
M__\7H`I`^6```+1H"P"4W?__%^$#%JH```#P`"`+D8\$`)2@"@#YX/K_M&`+
M`)35__\7A0"`4L#__Q<@`(!2R_[_EQ[__Y<?(`/5'R`#U1\@`]4?(`/5'R`#
MU1\@`]4?(`/5'R`#U1\@`]4?(`/5'R`#U1\@`]4?(`/5'R`#U1T`@-(>`(#2
MY0,`JN$#0/GB(P"1Y@,`D>```+``_$?Y`P"`T@0`@-))__^7V/[_E^```+``
MR$?Y0```M(C^_Q?``U_6'R`#U1\@`]7@``#0`"`"D>$``-`A(`*1/P``Z\``
M`%3A``"P(=A'^6$``+3P`P&J``(?UL`#7];@``#0`"`"D>$``-`A(`*1(0``
MRR+\?]-!#(&+(?Q!D\$``+3B``"P0MQ'^6(``+3P`P*J``(?UL`#7]8?(`/5
M_7N^J?T#`)'S"P#Y\P``T&`B0CE``0`UX```L`#41_F```"TX```T``$0/F-
M_O^7V/__ER``@%)@(@(Y\PM`^?U[PJC``U_6'R`#U1\@`]7<__\7'R`#U1\@
M`]4?(`/5_X,*T0'@`)'C``"P8]!'^>)#`)']>P"I!.`!D?T#`)%1Y`!O\.4`
M;V4`0/GE3P'Y!0"`TH?D`&_C`P*J(P!`;2($P3QC.(`.001@;T`$6&]C""`N
M0@1(;R946$\`'#%.9*0@+R%42$_#'#!.`!RB3B$<)TX`'*-.!1RA3F2,GTR?
M``'KP?W_5/`?0:U"H`F1Y@]"K>'C`9'E$T.MX2/`/?'E`&\?(`/5(H#9/"%`
M`)$@`-\\`!PB;@`<(VX`'#!N\!RG3L<<IDYF'*-.`E1!3P`$86^C'*5.A1RD
M3B0<H4Y`'*!.`1PQ3B&`@#P_``+KP?W_5`<H0*DD,X_2""1!J410J_+E/T&I
M(W2=TN+\6]/L_$+30A0'JHQY!ZHA`0C*(]NM\B$`"HHA``G*I0`$BR)`(HM!
M_4+3"Q!`^2%X"JHM?$"20@`%BZ4!",I"``L+YD-"J:4`!XJE``C*[P$$BT[\
M6].E``F+SA4"JB$`#,JE``^+(0`"BJ4`#@M/_$+3(0`-RN)Y`JK&``2+KOQ;
MTR$`"(O.%06J(0`&BX8!`LHA``X+C'U`DL8`!8JN_$+3Q@`,RA`"!(O&``V+
M+_Q;T\UY!:KO%0&J[AM`^44`#<K&`!"+0GQ`DL8`#PNE``&*I0`"RC#\0M/.
M`02+I0`,B\_\6],,>@&J[Q4&JJ4`#HNE``\+H0$,RL_\0M,A``:*YGD&JJU]
M0)+NOT.I(0`-RB$``HNP_$+3P@$$BZ[\6],A``*+@@$&RD(`!8J,?4"2SA4%
MJD(`#,HN``X+!7H%JN$!!(M"``V+0@`!B\$`!<K0?$"2(0`.BB$`$,K-_5O3
M(0`,BZT5#JKOLT2I30`-"\;]0M/.>`ZJIGQ`DN(!!(NO_5O3(0`"BZ(`#LKO
M%0VJ0@`-BB\`#PNE_4+30@`&RH$!!(NE>`VJ0@`0BT(``8OL_5O3P0$%RO#]
M0M.,%0^J(0`/B@]Z#ZI,``P+[<-%J<Y]0)(A``[*(0`&BX;]6]/&%`RJH@$$
MBQ`"!(LA``*+H@`/RBT`!@NE?$"20@`,BH;]0M-"``7*QG@,JJ']6]-"``Z+
M0@`0BRP4#:JP_4+3X0$&RB$`#8H->@VJ[L-&J4P`#`OO?4"2(0`/RB$`!8N%
M_5O3I10,JL(!!(L0`@2+(0`"B\(`#<HN``4+QGQ`DD(`#(J%_4+30@`&RJ5X
M#*K!_5O30@`/BT(`$(LL%`ZJT/U"TZ$!!<HA``Z*#GH.JN_#1ZE,``P+K7U`
MDB$`#<HA``:+AOU;T\84#*KB`02+$`($BR$``HNB``[*+P`&"Z5\0))"``R*
MAOU"TT(`!<K&>`RJX?U;TT(`#8M"`!"++!0/JO#]0M/!`0;*(0`/B@]Z#ZKM
MPTBI3``,"\Y]0)(A``[*(0`%BX7]6].E%`RJH@$$BQ`"!(LA``*+P@`/RBT`
M!0N%_4+3I7@,JD(`#(JA_5O3QGQ`DBP4#:KA`07*(0`-BN]]0))"``;*(0`/
MRD(`#HLA``:+[IM)J4(`$(M,``P+L/U"TPUZ#:J0_4+3P@$$BX[]6],A``*+
MSA4,JJ(`#<HN``X+I7Q`DD(`#(I"``7*#'H,JL$`!(M"``^+QOU;TT(``8OO
M5T#YH0$,RL84#JJM?4"2T@`""R$`#HHA``W*Y`$$BR$`!8O0_4+31?Y;TPYZ
M#JKO6T#Y(0`$BZ44$JI&0":+L``!"X0!#LJ$``9*X@$#BX0`#8L&_EO33?Y"
MTX0``HOB7T#YLGD2JL84$*HE0"6+SP`$"\$!$LHE``5*00`#BZ)`+(L,_D+3
MY?U;TXUY$*I"``&+I10/JN%C0/FQ``(+AD`FBT0"#<J$``9*[/U"TR8``XN!
M0"Z+)/Y;TX]Y#ZHA``:+A!01JN9G0/F0``$+14`EBZ(!#\I%``5*+OY"T]%Y
M$:JL0#*+P@`#BP7^6]/F:T#Y@@$"BZ44$*HD0"2+X0$1RJX``@LD``1*#/Y"
MT\$``XN&0"V+D'D0JL$``8OF;T#YQ/U;TT5`)8N$%`ZJ(@(0RHT``0M"``5*
MQ@`#BT)`+XO,_4+3CGD.JD(`!HOF<T#YI?U;TZ44#:HD0"2+`0(.RJ\``@LA
M``1*K/U"TXUY#:K&``.+(4`QB^3]6],A``:+14`EB^9W0/G"`0W*A!0/JD4`
M!4J1``$+K$`PB_#]0M/"``.+YGM`^0]Z#ZHE_EO3)$`DBZ$!#\J"`0*+I101
MJB0`!$JP``(+P0`#BRS^0M.&0"Z+C'D1JL$``8OF?T#Y14`EBP3^6]/B`0S*
MA!00JD(`!4J.``$+Q@`#BT)`+8L-_D+3\8-`^4(`!HNF>1"J)$`DB\7]6].!
M`0;*I10.JB$`!$JM``(+,`(#BR%`+XO/_4+3(0`0B^YY#JKPAT#YI/U;TX04
M#:I%0"6+L?U"T\(`#LJ/``$++7H-JD4`!4H"`@.+\(M`^21`)(O!`0W*K$`L
MBR0`!$KE_5O3I10/JH9`)HOQ_4+3`0(#B\$``8N"`0*+)GH/JJP``@M%0"6+
MH@$&RD(`!4J$_5O30D`NBX04#*KPNU&ID?U"TX\``0LL>@RJ)$`DB\$`#,KE
M_5O3(0`$2O']0M.E%`^J$`(#BR]Z#ZI"`!"+(4`MB^W'4JFP``(+S@$#BT5`
M)8L$_EO3(0`.BX04$*J"`0_*C@`!"T(`!4I"0":+I0$#BPW^0M-%``6+QOU;
MTZ)Y$*K&%`ZJ)$`DB^$!`LK-``4+)``$2B$"`XN$0"R+T?U"T_"?0/F$``&+
MK/U;TR%Z#JJ,%0VJID`FBT4``<J.`00+I0`&2A`"`XNE0"^+K_U"T^]Y#:JE
M`!"+\*-`^<;]6]/&%`ZJC$`LBR0`#\K-``4+C``,2M']0M,$`@.+@D$BB[#]
M6]-"``2+)'H.JJ9`)HOLIT#Y$!8-JN4!!,I"`!`+I0`&2J[]0M.A0"&+Q7D-
MJH8!`XM._$+3C``%JD/\6]-C%`*JC`$"BL)Y`JHA``:+[3M5J2$``PNC``0*
MAIN7THP!`ZIFX['R@T$OBR_\0M.L`0:++?Q;TZT5`:IC``R+K``"JF,`#0N,
M`0&*30`%"HP!#:KA>0&JS@$&BX1!)(MM_%O33``!JJT5`ZJ$``Z+A``-"XP!
M`XHM``(*;OQ"TXP!#:J-_%O3A4$EB\QY`ZKO.U:IHQ4$JBT`#*KO`0:+S@$&
MBZ4`#XN/_$+3HP`#"Z4!!(J-`0$*I0`-JFW\6].E0"*+XGD$JJT5`ZJ$`0*J
MI0`.BX0``XJE``T+30`,"H0`#:IM_$+3A$`ABZ%Y`ZKO-U>IKOQ;T\X5!:I#
M``&J8P`%BN\!!HNM`0:+A``/BZ_\0M.$``X++@`""F,`#JKE>06J8T`LBX[\
M6]/.%02J+``%JF,`#8N,`02*[<-`^6,`#@NN``$*C_Q"TXP!#JKD>02J@D$B
MBV[\6].L`0:+SA4#JNW'0/E"``R+K``$JD(`#@N,`0.*C@`%"HP!#JIO_$+3
MXWD#JJT!!HN!02&+3OQ;T\X5`JJ,``.J(0`-BXP!`HHA``X+;@`$"HP!#JI.
M_$+3PGD"JH5!)8OM.UFI+_Q"TZP!!HLM_%O3K14!JJ4`#(ML``*JI0`-"XP!
M`8I-``,*C`$-JN%Y`:K.`0:+A$$DBZW\6]-,``&JK14%JH0`#HN$``T+C`$%
MBBT``@JN_$+3C`$-JHW\6].#02.+S'D%JN\[6JFM%02J)0`,JJ4`!(KO`0:+
MS@$&BV,`#XN/_$+38P`-"XT!`0JE``VJY'D$JJ)`(HMM_%O3K14#JH4!!*I"
M``Z+I0`#BD(`#0N-``P*I0`-JFW\0M.A0"&+I7D#JN\W6ZE._%O3SA4"JH,`
M!:IC``**[P$&BZT!!HLA``^+KP`$"B$`#@MC``^J3OQ"TVQ`+(O">0*J(_Q;
MTXP!#8MC%`&JK0`"JB_\0M.#`0,+K`$!BN%Y`:I-``4*[C]<J8P!#:J$022+
M;?Q;TZT5`ZK,`0:++@`""H0`#(M,``&JA``-"XP!`XJ,`0ZJ;?Q"TZUY`ZKO
M`0:+A4$EBX[\6]/LZT#YHP`/B\X5!*HE``VJ8P`."Z4`!(JN`0$*C_Q"TZ4`
M#JIN_%O3HD`BBX4!!HOD>02JSA4#JD(`!8NE`02J0@`."V[\0M.E``.*PWD#
MJNR[7:F/``T*I0`/JD_\0M.E0"&+0?Q;TR$4`JJ,`0:+I0`,BXP``ZJE``$+
MC`$"BF$`!`KB>0*JC`$!JE```PJ!02V+S0$&BZS\6],A``V+[_=`^6T``JJ,
M%06JK0$%BHX!`0NM`1"JI$$DB[#\0M/M`0:+QOU;T^_[0/F$``V+QA0.J@UZ
M!:K1``0++$`LBT$`#<K%.IC2(0`,2D5,N?(A0".+[`$%B]#]0M,C_EO3[_]`
M^0YZ#JIC%!&J(0`,BVP``0N&0":+I`$.RB-`(XN$``9*Y@$%BX)`(HLO_D+3
MA/U;T_%Y$:I"``:+A!0,JN8#0?F2``(+P0$1RD1`)(LC``-*P0`%BV9`+8N-
M_4+30_Y;T[!Y#*K&``&+8Q02JN$'0?EO``8+(@(0RDS^0M-"``1*)``%BT)`
M+HOA_5O3C7D2JD0`!(OB"T'Y(10/JBX`!`O#0".+!@(-RNS]0M/#``-*1@`%
MBV-`,8O"_5O3CWD/JF,`!HOF#T'Y0A0.JE$``PN!0"&+I`$/RF)`(HN!``%*
MQ``%BRQ`,(O0_4+3(?Y;TPYZ#JKF$T'YA`$$BR$4$:KC`0[*,``$"V(``DHL
M_D+3PP`%BT9`+8L"_EO3C'D1JL,``XOF%T'Y0A00JDT``PN!0"&+Q`$,RA'^
M0M.!``%*Q@`%BR1`+XNA_5O3[QM!^80`!HLA%`VJ)GH0JF)`(HLP``0+@P$&
MRN\!!8MB``)*L?U"TT-`+HL"_EO3[A]!^2UZ#:IC``^+0A00JD\``PN!0"&+
MQ``-RF)`(HN!``%*Q`$%BRQ`+(L._D+3X?U;T]!Y$*J$`02+(10/JNPC0?DQ
M``0+HP$0RH%`(8MB``)*@P$%BT9`)HOL_4+3(OY;TX]Y#ZK#``.+0A01JN8G
M0?E.``,+!`(/RF)`(HN!``%*Q@`%BR1`+8LM_D+3P?U;TX0`!HOL*T'YIGD1
MJB$4#JKC`0;*+0`$"V(``DJ,`06+0T`PB]#]0M.B_5O3#GH.JF,`#(OL+T'Y
M0A0-JE$``PN!0"&+Q``.RF)`(HN!``%*A`$%BRQ`+XNO_4+3(?Y;T^UY#:J$
M`02+(101JNPS0?DP``0+PP$-RB_^0M-B``)*C`$%BT)`)HL#_EO31@`,BV,4
M$*KB-T'Y['D1JH%`(8MO``8+I`$,RL-`(XN$``%*00`%BX1`+HOB_5O3#OY"
MTX0``8OQ.T'YP7D0JD(4#ZJ&`0'*3@`$"\,``THP`@6+9D`MB_']0M/#_5O3
M[3]!^6,4#JHO>@^JQ@`0BW``!@N"0"*+)``/RL9`(XN$``)*H@$%BXQ`+(O-
M_4+3!/Y;TXP!`HOB0T'YA!00JJYY#JJ#``P+[0$.RN=`+XNM`09*1@`%BZ%!
M(8MB_%O30A0#JB$`!HOM1T'Y(0`""P+^0M.&022+0G@0JB3\6]/,`0+*A!0!
MJHP!!DJF`06+9?Q"T\8`!XNC>`.JA``,B^<``)#GT$?Y(0`*"T(`"0O%`0L+
MA``&"V,`"`L$!`"I`P@!J040`/GB3T'YX0!`^4(``>L!`(#2@0``5/U[0*G_
M@PJ1P`-?UIOZ_Y<?(`/5'R`#U?U[O*G]`P"1\U,!J:`&`+3W8P.I]P,`JN``
M`)``^$?Y&`!`^3@&`+3U6P*I]@,!JA4`@%+@`D`Y'_0`<0080'K!`@!4$P-`
M^=,!`+2U?D"3]`,8JA\@`]7B`Q6JX0,7JN`#$ZI'^O^7@```-6!J=3@?]`!Q
M``(`5)..0/CS_O^U]5M"J?=C0ZG@`Q.J\U-!J?U[Q*C``U_6]0,7JJ`>0#@?
M]`!Q!!A`>J'__U2U`A=+Y?__%X`"&,NU!@"1<P(5BP#\0Y/``@"YX`,3JO-3
M0:GU6T*I]V-#J?U[Q*C``U_6$P"`TNG__Q?W8T.I$P"`TN;__Q?]>[6IX@``
MD$+01_G]`P"1\PL`^>&C`)'S`P"J0P!`^>-7`/D#`(#28?K_ER`"`#7A.T"Y
M`@"44B$,%!(_$$!Q)!!">J`!`%3A``"0(=!'^>-70/DB`$#Y8P`"ZP(`@-*!
M`0!4\PM`^?U[RZC``U_6``"`4O7__Q?@`Q.J00"`4@OZ_Y<?``!QX!>?&N__
M_Q<W^O^7'R`#U1\@`]7_0T#1_P,"^?]#`=%"`(!2X0``D"'01_GC0T"1_7L`
MJ?T#`)'U6P*I]0,`*A8!@-+W&P#Y-@"@\B0`0/ED)`#Y!`"`T@$`@-*B^?^7
M%P0`T>`#%^OA/D"2`#Q`DB!$@-KW`@#K!`8`5/-3`:GS`P&1]```L!\@`]7A
M`Q>J`@"`4N`#%2J3^?^7X@,6JN$#$ZK@`Q4J`_K_EP!\0),?'`#QJ0,`5`$@
M`-%A`@&KHP``5!D``!0A!`#1/P`3Z\,"`%0C`$#Y@@I`^7\``NM!__]4(0`3
MR_-30:D@`!>+X0``D"'01_GC0T"19"1`^2(`0/F$``+K`@"`TJ$!`%3]>T"I
M]5M"J?<;0/G_0P&1_T-`D<`#7];W0D#1_T)`L>'Z_U3S4T&I``"`DNW__Q?S
M4P&IZ/G_E^$``)`AT$?Y_7NTJ?T#`)$B`$#YXE\`^0(`@-+```"T\U,!J?,#
M`*H!`$`Y80$`-?-30:G@``"0`-!'^>)?0/D!`$#Y0@`!ZP$`@-*!"`!4_7O,
MJ,`#7];U6P*IZ/G_E_0#`*I`!@"TX`,4JH#Y_Y=@!0"T`4Q`.15,`)$_N`!Q
M80``5*$&0#D!__\T`$Q`.1^X`'$@!0!4X`,3J@SZ_Y?V`P"JX`,5J@GZ_Y?`
M`@`+``@`$0!\0)/!^?^7Y0,5JN0#$ZH#``#08V`)D0(`@)+U`P"J(0"`4@'Z
M_Y?@`Q6JX>,`D7KY_Y<?!``QH```5.!+0+D`#!02'Q!`<:`"`%3@`Q6J&OG_
ME^`#%:K8^?^7X`,4JE;Y_Y?@^O^UX`,4JF/Y_Y?@`Q.J>?G_E_-30:GU6T*I
MP/__%Z`&0#D?N`!QP?K_5*`*0#D`^?\TT___%^`#%:JK__^7[/__%_-3`:GU
M6P*ICOG_EQ\@`]7]>[ZI(P``T`$``-#]`P"1\U,!J530.]7S``"0<^9'^>(`
M`)!"Z$?Y8\`.D2&`"9&`:G/XM_G_EX!J<_@$``#0\U-!J83`%I']>\*HXP,$
MJN(``)!"S$?Y`0``T`4`@%(A``J14_G_%Q\@`]4?(`/5#`B"TO]C+,OC``"0
M8]!'^>+_@=+]>P"I_0,`D?-3`:GS`P"J]`,!JO5;`JGUXP"1X0,5JF``0/G@
M'PCY``"`T@```-``8`J1ZOC_EQ\``''-``!4!`0`4>(#`"J@RF0X``,`-:0"
M`#7@``"0`.1'^4/0.]7B`Q2JX0,3JF!H8/CT^/^7X```D`#01_GB'TCY`0!`
M^4(``>L!`(#2`0,`5/U[0*D,"(+2\U-!J?5;0JG_8RR+P`-?UN(#!"H?(`/5
M5GQ`D^`#%:KB`Q:JX06`4FSY_Y>@_/^TX```D`#D1_E$T#O5XP,6JN(#%:KA
M`Q.J@&A@^"_Y_Y?C__\7,?G_E_U[NJG]`P"1\U,!J?,#`*KT`P&J]5L"J?=C
M`ZG@``"0`-!'^2$`0#D"`$#YXB\`^0(`@-(_]`!QE!:4FN`#%*IL^?^7]@,`
MJN%3`9'@`Q.JA/[_ET`(`+3U`P"J9?G_E]\"`.OI!@!4]U>`N?@``)`8^T?Y
M]_)]TV`"0#D?]`!Q!!A`>N`+`%3D`Q.J'R`#U8,<0#A_]`!Q9!A`>J'__U2$
M`!/+A'Q`DQ4#0/G`"@"1```$BPOY_Y>@:C?XH`(`M`$#0/G@`Q.J(VAW^`$4
M0#AA```Y/_0`<2080'K```!4`A1`.&(<`#A?]`!Q1!A`>H'__U2A!X!2``"`
MTF$4`#B":F`X8F@@.``$`)&B__\UX```D`#01_GB+T#Y`0!`^4(``>L!`(#2
M80<`5/-30:GU6T*I]V-#J?U[QJC``U_6`0"`TA\@`]6":F$XHFHA."$$`)&B
M__\U[O__%_@``)`8^T?Y^6L$J1H#0/E``T#YP`0`M.`#&JH5`(!2'R`#U0&,
M0/CB`Q4JM08`$:'__[5`#``1`'Q]D^$``+`BD$"Y`@(`-2(`@%(BD`"YS?C_
ME_D#`*I``P"TMWY]D^$#&JKB`Q>J__C_EQD#`/F@!@`1]5<`N3_;(/CY:T2I
MI___%^$#`*K@`QJJ7OC_EP`#`/GY`P"J0`$`M+=^?9/T__\7!`"`TJG__Q<`
M`H#2%0"`4N+__Q?Y:P2IJOC_E_EK1*F\__\7X```D`#D1_E$T#O5X@``D$+H
M1_DC``#0`0``T&/`#I&`:&#X(8`)D=7X_Q<,"H32_V,LR^```)``T$?Y`0B"
MTOU[`*G]`P"1\U,!J?-C(8OU$P#Y]>,`D0$`0/GA)Q#Y`0"`TA[X_Y?D`P`J
M!0``T`,``-"EH`J18\`*D2(`@M(A`(!2X`,3JM7X_Y?@`Q.JX0,5J@(`@M(-
M^/^78`/X-_,#`*H`!``1`'Q`DX3X_Y?T`P"JH`(`M'-^0)/A`Q6JX@,3JA;X
M_Y>?:C,XX```D`#01_GB)U#Y`0!`^4(``>L!`(#2`0$`5/U[0*G@`Q2J\U-!
MJ0P*A-+U$T#Y_V,LB\`#7]9F^/^7%`"`TO#__Q?'__\7'R`#U1\@`]4,'(+2
M_V,LR^(``)!"T$?Y_7L`J?T#`)'S4P&I\P,!JN%3`9'U6P*I]0,`JD``0/G@
M;PCY``"`T@```-``(`N1N/W_E_0#`*KA!8!2X`,5JG#X_Y=@`@"TX0,5J@``
M`-``8`N1%___E^`#%:KA``"0(=!'^>-O2/DB`$#Y8P`"ZP(`@-+A#`!4_7M`
MJ0P<@M+S4T&I]5M"J?]C+(O``U_6X`,3JE/X_Y<6``#0P:(+D;CW_Y?S`P"J
M`/W_M/=C`ZD8``#0]V,#D1CC"Y'Y:P2I&0``T#G#"Y%@`D`YH`8`-+0``+3A
M`Q.JX`,4JCGX_Y<`!0`TX`,3JF[X_Y<"!`#1^@,`JF("`HM_`@+KHP``5`H`
M`!1?]!\X?P("ZX```%1``$`Y'[P`<6#__U3@`Q.J8/C_E_H#`*K@`Q6J7?C_
MEP``&HL`!`"1'_P_\<@"`%3D`Q.JY@,5JN4#&:KC`QBJ`@""TB$`@%+@`Q>J
M5?C_E^%C`9'@`Q>JSO?_EZ```#7@:T"Y``P4$A\@0'&``@!4P:(+D0``@-)^
M]_^7\P,`JL#Y_[7W8T.I^6M$J:O__Q<4`P"T@`)`.1^X`'&@``!4$P``T#H`
M@-)S`@N1V___%X`&0#G@_?\T^O__%^`#%ZHA`(!2M_?_ET#]_S7A`Q>J````
MT`!@"Y&R_O^7X`,7JOSW_Y?W8T.I^6M$J9C__Q<3``#0.@"`TG,""Y''__\7
M]V,#J?EK!*G6]_^7'R`#U?U[OJGA!8!2_0,`D?,+`/GS`P"J?_?_EQ\``/%@
M!H":\PM`^?U[PJCF]_\7'R`#U0P(@M+_8RS+X0``D"'01_G]>P"I_0,`D2(`
M0/GB'PCY`@"`T@`&`+3U$P#Y]0,`J@$`0#EA!0`T\U,!J07X_Y<"!`"1\P,`
MJE\$0/&H!@!4].,`D>$#%:K@`Q2J4??_EV`&`-&``@"+'P`4ZZ@``%0'```4
M'_0?.!\`%.N```!4`0!`.3^\`'%@__]4X`,4JN$%@%)3]_^7@`0`M!\`%.O(
M`P!4X`,4JKKW_Y?A``"0(=!'^>,?2/DB`$#Y8P`"ZP(`@-*A!`!4_7M`J0P(
M@M+S4T&I]1-`^?]C+(O``U_6]1-`^>```)``T$?YXA](^0$`0/E"``'K`0"`
MT@$#`%0```#0```+D?U[0*D,"(+2_V,LBY_W_Q<?```YXO__%P``@-+B__\7
MX```D`#01_GB'TCY`0!`^4(``>L!`(#2P0``5/-30:D```#0]1-`^0``"Y'M
M__\7<O?_E_-3`:GU$P#Y;_?_EQ\@`]4?(`/5_7NZJ>```)``T$?Y_0,`D?-3
M`:D4``#0\U,!D?5;`JF4`@R1]V,#J?DC`/GU``"0M?I'^0$`0/GA+P#Y`0"`
MTN$#$ZK@`Q2JPOS_E^`!`+2B`D#YXU>`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y
M`00`^0`@`)&A__^UX0,3JN`#%*JT_/^78/[_M=4``/"U^D?Y%```L)1"#)'A
M`Q.JX`,4JJS\_Y?@`0"TH@)`^>-7@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$
M`/D`(`"1H?__M>$#$ZK@`Q2JGOS_EV#^_[75``#PM?I'^10``+"48@R1X0,3
MJN`#%*J6_/^7X`$`M*("0/GC5X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y
M`"``D:'__[7A`Q.JX`,4JHC\_Y=@_O^UU0``\+7Z1_D4``"PE*(,D>$#$ZK@
M`Q2J@/S_E^`!`+2B`D#YXU>`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@
M`)&A__^UX0,3JN`#%*IR_/^78/[_M=8``/#6^D?Y%```L)7"#)'A`Q.JX`,5
MJFK\_Y?@`0"TP@)`^>-7@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1
MH?__M>$#$ZK@`Q6J7/S_EV#^_[76``#PUOI'^14``+"U`@V1X0,3JN`#%:I4
M_/^7X`$`M,("0/GC5X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'_
M_[7A`Q.JX`,5JD;\_Y=@_O^UUP``\/?Z1_D5``"PMB(+D>$#$ZK@`Q:J/OS_
ME^`!`+3B`D#YXU>`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^U
MX0,3JN`#%JHP_/^78/[_M=@``/`8^T?Y%@``L-="#9'A`Q.JX`,7JBC\_Y?@
M`0"T`@-`^>-7@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$#
M$ZK@`Q>J&OS_EV#^_[79``#P.?M'^1<``+#X@@V1X0,3JN`#&*H2_/^7X`$`
MM"(#0/GC5X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A`Q.J
MX`,8J@3\_Y=@_O^UV0``\#G[1_D8``"P&,,-D>$#$ZK@`QBJ_/O_E^`!`+0B
M`T#YXU>`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3JN`#
M&*KN^_^78/[_M=D``/`Y^T?Y&```L!AC"Y'A`Q.JX`,8JN;[_Y?@`0"T(@-`
M^>-7@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$#$ZK@`QBJ
MV/O_EV#^_[7A`Q.J````L```#I'3^_^7X0,`JF```+3@@@V1-_W_E^$#$ZH`
M``"P`&`.D<O[_Y?A`P"J@```M````+``P`Z1+OW_E^$#$ZH```"P```/D<+[
M_Y?A`P"J8`(`M*`B"Y$F_?^7P```\`#01_GB+T#Y`0!`^4(``>L!`(#280(`
M5/5;0JF`P@R1\U-!J0$``+#W8T.I(:`/D?DC0/G]>\:H%OW_%^$#$ZH```"P
M`$`/D:K[_Y?A`P"J8/W_M,!"#9$._?^7Z/__%SSV_Y?"``#P0M!'^?U[OJD`
M``"P_0,`D4,`0/GC#P#Y`P"`TN%3`)$`0`V1F?O_E\`!`+0``$`Y'\``<008
M0'K@!Y\:P0``\"'01_GC#T#Y(@!`^6,``NL"`(#2H0``5/U[PJC``U_6``"`
M4O;__Q<@]O^7_7N_J?T#`)$%]O^7L/7_ET```+0``$#Y_7O!J,`#7];]>[RI
MP0``\"'01_G]`P"1\U,!J?0#`*KU6P*I%0``L+;"#Y$B`$#YXA\`^0(`@-+@
M`Q:JX=,`D7'[_Y>```"T`0!`.?,#`*K!`0`UP```\`#01_GB'T#Y`0!`^4(`
M`>L!`(#2(08`5.$#%*J@P@^1\U-!J?5;0JG]>\2HR/S_%^$#%*JR]?^7@`$`
MM,```/``T$?YXA]`^0$`0/E"``'K`0"`TB$$`%3S4T&I]5M"J?U[Q*C``U_6
MX`,4JC3V_Y?U`P"JX`,3JC'V_Y>@`@"+``@`D>KU_Y?F`Q.J`@"`DB$`@%+D
M`Q2J\P,`J@4``+`#``"PI:`+D6/@"Y$H]O^7P```\`#01_GB'T#Y`0!`^4(`
M`>L!`(#2@0``5.$#$ZK@`Q:JT___%\WU_Y?_PP71X0``D"%``)'BXP*1)*``
MD?U[`:G]0P"1PP``\&/01_GS4P*I\R,"D28<0:GU6P.I]0,`JBBD1:GW8P2I
M^(,"D8$(0*U@`$#YX+<`^0``@-*`",`]]/,!D2000/D6``"P(S1`^<`B"Y'A
M`Q2J00@`K6,*`/D$"P#Y0`B`/>BG"*GF'PJI$OO_EX```+0!`$`Y]P,`JJ$@
M`#7Y:P6IC/7_ES?U_Y=`#P"T&0!`^1D/`+3@`QFJZO7_EP#X?],`!`"1H_7_
ME_,#`*HD`T`Y]P,`JF0!`#0:``"P6B,0D>`#$ZKC`QJJ`@"`DB$`@%+@]?^7
M<PH`D20?0#@D__\U````L/D#`Y$`P`Z1`P``%""'0/B@`0"TX0,4JNWZ_Y?S
M`P"J8/__M`$`0#DA__\T)?O_E^#^_S3@`Q.JF?7_E_,#`*I@`0"U$P-`^3,!
M`+1@`D`YP`L`-.`#$ZH:^_^7H`H`-1,'0/D8(P"1,___M>`#$ZJ[]?^7^`,`
MJN`#%ZJX]?^7&0,`"SD3$!$:``"P.7]`D^`#&:IN]?^7YP,7JN0#$ZI%PPN1
M!@``L`,``+#&0!"18V`0D0(`@)+X`P"J(0"`4JOU_Y?@`QBJ`3B`4H3U_Y<?
M!``QH0``5$'U_Y<%`$"YOT0`<>$4`%3[<P:I^Z,#D>`#&*KA`QNJ7?7_E_,#
M`"J@```UX/M`N0`,%!(?$$!Q@`8`5,```/``X$?YY`,8JJ,"0/D"``"P``!`
M^4*@$9$A`(!2-O7_E_MS1JD7`(#2P```\`#01_GBMT#Y`0!`^4(``>L!`(#2
MH1P`5/U[0:G@`Q>J\U-"J?5;0ZGW8T2I^6M%J?_#!9'``U_62/7_E_D#`*I@
M`@"U<R(`D6`"0/F@$@"TX0,4JHWZ_Y=@__^T`0!`.<'^_S5S(@"1^/__%^`#
M$ZH8(P"1.?7_E_,#`*H@]/^TJO__%Q,`@-*H__\78_7_EP#X?],`!`"1>?__
M%_<#0;GZ]/^7_P(`:T'Y_U3@^T"Y`"``$A\`!W'!^/]4X`,9JA+U_Y<!``"P
M]P,`JB``$Y'A`Q2J;?K_E^$#`*H@#P"TH`)`^:'\_Y?\`P"JH`X`M.`#'*I)
M]?^7^0,`JA\,`''-`0!4`'Q`DP$``+``$`#1(2`3D8`#`(L(]?^7X```-3\3
M`'%@$@!4.1<`48#+>3@?O`!QX!$`5.$#%*H4``"P@$(-D5'Z_Y>@``"T``!`
M.1_``'$$&$!ZP0``5.`#'*H!`(!2*?7_E_4#`"K@"@`U@$(-D0$``+`AH`^1
MJ_O_EUK#"Y$5``"PM<(6D1D``+!F]/^7.>,3D>8#`"KG`Q6JY0,:JN0#&*K@
M`Q>J`P``L`(`@))CH!.1(0"`4AOU_Y<1```4M?3_EP``0+D?1`!Q00(`5%7T
M_Y?U`P#Y<P8`$>8#`"KG`Q,JY0,:JN0#&*KC`QFJX`,7J@(`@)(A`(!2"O7_
ME^`#%ZH!.(!2X_3_EQ\$`#&`_?]4X`,8JN?T_Y?A`Q>JP"(+D8#[_Y?@`Q>J
ME_[_E_MS1JEQ__\7P```\`#@1_GD`QBJHP)`^0(``+```$#Y0J`0D2$`@%*;
M]/^79O__%XK^_Y?```#P`-!'^>*W0/D!`$#Y0@`!ZP$`@-*!"0!4_7M!J>`#
M%ZKS4T*I]5M#J?=C1*G_PP61K_3_%Z`!@-*9]/^7&0``L/,#`*HY`Q"1]P,`
MJF0*@%+U_O\7O`)`^8O__Q=4^O^7^0,`J@#U_[<!*`#1`@"`4N`#%2K\`P*1
M`?3_E^$#'*K@`Q4JP@"`TG'T_Y?A@T"Y`&"(4B!HJ'(_``!K0?/_5.$+07D`
MJ8A2/P``:\'R_U0ARP#1X`,5*@(`@%+P\_^7X0,;JN`#%2H"!8#28/3_E^8#
M&ZI%PPN1Y`,8JN`#%ZH'``"P`P``L.?`%I%C8!.1`@"`DB$`@%+_0P0YL/3_
MEZO__Q>U!D#Y->[_M.`#%:JG]/^7'PP`\:GM_U0`$`#1`0``L*`"`(LA0!.1
M:/3_EQ\``'&<$Y6:9?__%_MS!JE/]/^7^6L%J?MS!JE,]/^7_7N[J0```+``
MP`R1_0,`D?-3`:E4T#O5TP``\'/F1_GU6P*I]A,!D>$#%JKW&P#YP@``\$+0
M1_F5:G/X0P!`^>,G`/D#`(#2HL)".:+&`CF?^?^7@```M`$`0#D_Q`!Q``L`
M5,;\_Y>5:G/XX`,5J@$``+!C`(!2(4`4D2(`@%+'\_^7]0,`JF`!`+2A"D#Y
M`@``L(!J<_A"8!21(0!`^<?S_Y>@"D#Y`0!`^2`,0+G`";`W@&IS^`$``+!C
M`(!2(8`4D2(`@%+W``"0M//_E_4#`*I@`0"TX0,6J@```+``8`N1>OG_E^(#
M`*H`!P"TH0I`^8!J<_@A`$#YL//_EY5J<_@B`(!2`0``L"&@%)'@`Q6J?O/_
MEP(``+#A`P"J0@`5D>`#%:JE\_^7@FIS^/1"`I'A`Q:J````L``@"Y%?Q`(Y
M8OG_EX`*`/GS`P"J@`(`M`$X@%+@`Q.J(/3_EP$$`!$_!`!Q!(A1>F$$`%3`
M``#P`-!'^>(G0/D!`$#Y0@`!ZP$`@-)A`P!4\U-!J?5;0JGW&T#Y_7O%J,`#
M7]:`!D#Y%O[_EX`*`/GS`P"J(/W_M0```+``(!61_//_EP`$0#E`]?\TI___
M%^!"`I&B"D#Y`01`^4``0/DA`$#Y8_K_E\?__Q>`:G/XW//_E['__Q?.\_^7
M]T("D>,#`"KB`Q.J````L`#`%9'A!D#Y(0!`^>;S_Y<?(`/5_7N]J<$``/`A
MT$?Y_0,`D?-3`:GS`P"J(@!`^>(7`/D"`(#2\_O_E_0#`*KA!8!2://_EQ\`
M`/&`!H":T?/_E_0#`*KADP"1````L`!`#9$8^?^7(`$`M```0#D?P`!Q!!A`
M>N`'GQI_`@#QX0>?&C\``&IA`0!4P```\`#01_GB%T#Y`0!`^4(``>L!`(#2
MX0(`5/-30:G]>\.HP`-?UF`"0#F@_O\T`0``L.`#%*HA0!"1@@"`TE[S_Y?@
M_?\UP```\`#01_GB%T#Y`0!`^4(``>L!`(#2H0``5.`#$ZKS4T&I_7O#J*/Y
M_Q>)\_^7_7N_J0`0@-+]`P"1C?/_EQ\8`/DB``"P(0``L!]X`+E!Y,`](@``
ML"+@P#U`Z,`]`@0`K0`(@#W]>\&HP`-?UOU[O*E"?$"3_0,`D?-3`:D4X`"1
M\P,!JO5;`JGU`P"J]@,"JO=C`ZD%C$*I`'A`N:0,`@N_``3K8Y2#FF)T0HND
MB@*IH`,`-=_^`'&M!0!4U@(!4=A^!E,7!P`1]VIZTW<"%XL?(`/58`9`K>`#
M%:J`!@"M8`9!K7,"`9&`!@&MD/3_EW\"%^L!__]4UAH82^$#%ZK@`Q2JPGY`
MD_'R_Y>V>@"Y\U-!J?5;0JGW8T.I_7O$J,`#7]87"(!2]P(`2_\"%FN`PB"+
M]]*6&OA^0)/B`QBJX_+_EZ!Z0+G@`@`+H'H`N1\``7'A_?]4U@(72W,"&(O@
M`Q6J<O3_E]/__Q?W`Q.JX___%Q\@`]4?(`/5_7N\J>(/@!+]`P"1\U,!J?0#
M`*KS`P&J]5L"J3;@`)'H&P#]-11`^2@80/V@(@-3`00`$<+*(#C`PB&+/^``
M<4T+`%0""(!20@`!2P$`@%)"?$"3<_/_E^`#$ZI5]/^7?S8`^0`$`$_``@"M
MP`J`/04%<'\`!6A_!`5X?Z$"9Y[@`Q.J(P1H?R($<'^@!`-N(01X?X`$!6X`
M!0=N8`0);D`$"VX@!`UNH!X/3F`Z`/U`]/^780)`^>`#$ZHA_%C3@0(`.6$"
M0/DA_%#3@08`.6$"0/DA_$C3@0H`.6$"0/F!#@`Y809`^2'\6-.!$@`Y809`
M^2'\4-.!%@`Y809`^2'\2-.!&@`Y809`^8$>`#EA"D#Y(?Q8TX$B`#EA"D#Y
M(?Q0TX$F`#EA"D#Y(?Q(TX$J`#EA"D#Y@2X`.6$.0/DA_%C3@3(`.6$.0/DA
M_%#3@38`.6$.0/DA_$C3@3H`.6$.0/F!/@`Y81)`^2'\6-.!0@`Y81)`^2'\
M4-.!1@`Y81)`^2'\2-.!2@`Y81)`^8%.`#GS4T&I]5M"J>@;0/W]>\2H__+_
M%P('@%)"``%+`0"`4D)\0),:\_^7K?__%\,``/!C!$#YLO+_%Q\@`]7]>[^I
M_0,`D?U[P:C``U_6`0`"```````E<R\E<P```$1Y;F%,;V%D97(Z.F)O;W1?
M1'EN84QO861E<@``````26YT97)N86QS.CI005(Z.D)/3U0`````+W!R;V,O
M<V5L9B]E>&4``&5X90``````+W!R;V,O)6DO)7,``````"X`````````4$%2
M7U1%35```````````%!!4E]04D]'3D%-10`````Z`````````"\`````````
M)7,E<R5S``!015),-4Q)0@``````````4$523$Q)0@!015),-4]05```````
M````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140``````%!!
M4E]#3$5!3@````````!005)?1$5"54<`````````4$%27T-!0TA%````````
M`%!!4E]'3$]"04Q?1$5"54<``````````%!!4E]'3$]"04Q?5$U01$E2````
M`````%!!4E]435!$25(```````!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!
M3%]#3$5!3@``````````,0````````!,1%],24)205)97U!!5$@`4UE35$5-
M```E,#)X`````'!A<BT`````)7,E<R5S)7,``````````"5S.B!C<F5A=&EO
M;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I
M*0H````````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E
M("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*
M````````4$%42`````!P87)L`````"YP87(`````)7,E<V-A8VAE+25S)7,`
M`"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S```````````8````
M`````'!E<FP`````,`````````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q
M+C`U.````%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y````````
M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*```````````M90```````"TM````````
M979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF
M(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?
M<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C
M86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N
M<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD
M8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-04=)0R`](")02UPP,#-<
M,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM
M>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@
M/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D
M8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O
M9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D
M<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H
M)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-
M04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C
M:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O
M9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.
M5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER
M(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ
M<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD
M.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@
M)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP
M("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI4
M96UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S
M96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.
M3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*
M<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=
M.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP
M)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID
M;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P
M+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@
M,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R
M;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D[
M"GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I
M;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E
M;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]
M("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z
M)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG
M=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@
M+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H
M*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P
M87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!
M4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E
M8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![
M?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U
M=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@
M9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S
M="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&
M2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@
M;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B
M72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O
M<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D
M1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D
M(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<
M,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H
M92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE
M(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@
M+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%
M7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD[
M"F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B
M*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M
M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&
M2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*
M=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR
M96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M
M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N
M+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]
M*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H
M)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U
M9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H
M9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD
M+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U
M9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]
M("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65]
M(#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE
M?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL
M;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?
M1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L
M("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO
M9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R
M;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]
M.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF
M("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I
M*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A
M;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F
M:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U
M<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN
M9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]
M("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O
M<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@
M)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@
M;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97([
M"G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M
M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D
M24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF
M("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M
M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@
M+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES
M='LD9FEL96YA;65].PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO
M=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL
M92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@
M*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP
M"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D
M8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A
M;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H
M(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F
M)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A
M<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?
M<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@
M97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D55
M4T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H
M879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;
M,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@
M*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H
M)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!
M)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/
M)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE
M(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A
M;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I
M9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@
M<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q
M(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*
M:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=0
M05)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB
M4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES
M=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)
M3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/
M.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z
M.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H
M9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R
M(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S
M<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<[
M"B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@
M>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF
M("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM
M;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<
M4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT[
M"FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P
M87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T[
M"FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES
M(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,[
M"F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&
M:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@
M;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M
M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD
M969I;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L
M;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L
M("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%2
M7U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0
M;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L
M;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U
M="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E
M<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]
M"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG
M.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I
M9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E
M86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO
M861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB
M7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A8
M6"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@
M)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*
M:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E
M('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1
M)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I
M.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\
M*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q
M(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*
M?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W
M<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL
M92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K
M:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@
M.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O
M;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD
M968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E
M("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L
M("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ
M4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N
M86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D
M;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ
M8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N
M9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I
M=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R
M:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I
M=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R
M(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*
M:68@*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I
M.PI]"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T
M>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X
M+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]
M("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C
M:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@
M(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE
M*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D
M;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R
M:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO
M<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z
M("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S
M(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E
M(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I
M<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H
M+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I
M(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?
M1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI
M=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V
M-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,
M:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z
M:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U
M;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H
M("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O
M<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT
M('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N
M9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X
M=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^
M8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M
M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D
M4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN
M8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS
M92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E
M<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D
M9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q
M<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B
M73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*
M?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*
M9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A
M<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G
M<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!
M4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E
M>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ
M)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D
M<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R
M<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U
M:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I
M8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#
M87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U
M:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER
M92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P
M96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E
M($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E
M<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U
M:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A
M='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I
M<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V
M86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@
M<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q
M=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![
M(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E
M9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H
M+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@
M)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@
M5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@
M>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@
M+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W
M=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F
M:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS
M,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E
M<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%
M4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D
M:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S
M97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7([
M"FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D
M(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O
M<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY
M("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E
M96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG
M=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE
M;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E
M:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T
M:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L
M("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A
M8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H
M(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM0
M05)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A
M8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0
M?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B
M(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?
M.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M
M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"([
M"FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP
M<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;
M17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@
M)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L
M("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F
M=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%
M3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H
M+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII
M9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM0
M05)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M
M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF
M("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y
M<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O
M9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M
M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U
M<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S
M97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%2
M7U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O
M7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[
M7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D
M:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA
M;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M
M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P
M<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-
M17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2![
M"B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D
M<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*
M.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I
M(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN
M7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[
M4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N
M=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T
M=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O
M<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-
M12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U0
M1$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%
M3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!
M3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM0
M05)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII
M9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R
M:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG
M.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I
M9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@
M<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A
M8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z
M.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R
M+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S
M=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64[
M"F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?
M15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2
M(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D
M.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!54T52`````%5315).04U%````````
M``!435!$25(``%1%35!$25(`5$5-4`````!435```````"]T;7``````````
M```````!(T5G`````(FKS>\`````_MRZF`````!V5#(0`````/#ATL,`````
M``````````!P97)L>'-I+F,``````````$-!0TA%```!&P,[!`$``!\```#X
MBO__P`8``#B-__\<`0``B(W__S`!``"XC?__1`$``/B-__]8`0``2([__WP!
M``!8CO__D`$``!B?__^T`0``#*#__QP"``"HH/__1`(``-RA__^P`@``2*/_
M_P`#``"XH___)`,``+BD__]<`P``W*;__[`#```(I___Q`,``.RG___X`P``
M^*?__PP$```HJO__>`0``%BJ__^<!```R*O__PP%``",L/__2`4``/RP__]H
M!0``'+'__X@%``!(LO__Q`4``$RX__]8!@``:+K__XP&``!8N___\`8``)B[
M__\0!P``J+S__T@'``!HOO__@`<````````0``````````%Z4@`$>!X!&PP?
M`!`````8````%(S__S0`````00<>$````"P```!0C/__,``````````0````
M0````&R,__\\`````````"````!4````F(S__T@`````00X@G02>`T*3`D[>
MW=,.`````!````!X````Q(S__P0`````````(````(P```#`C/__N!````!!
M#J`%1IU4GE,#)00*W=X.`$$+9````+````!<G?__]`````!!#D"=")X'0I,&
ME`5"F`&7`D:6`Y4$5M;50=C70][=T]0.`$$.0),&E`65!)8#EP*8`9T(G@=/
MUM5!V-=!WMW3U`X`00Y`DP:4!9T(G@="EP*8`4'8UP`D````&`$``.B=__^4
M`````$$.L`&=%IX51),45@K>W=,.`$$+````:````$`!``!<GO__-`$```!!
M#H"`!$(.T(`$19V*0)Z)0$*5AD"6A4!(EX1`292'0).(0%O4TTS=WM?5UD$.
M@(`$00X`00[0@`23B$"4AT"5AD"6A4"7A$"=BD">B4!$U--#E(=`DXA`````
M3````*P!```DG___:`$```!##L`!G1B>%T:4%9,61-332-[=#@!!#L`!DQ:4
M%9T8GA=!EA.5%'4*U--!UM5!"TG3U-760905DQ9!EA.5%``@````_`$``$"@
M__]H`````$$.()T$G@-$DP*4`4[>W=/4#@`T````(`(``(R@__\``0```$(.
MP"!$G8@$GH<$0I.&!)2%!$.5A`26@P1B"MW>U=;3U`X`00L``%````!8`@``
M5*'__R0"````00Y@G0R>"T*3"I0)394(E@>7!I@%?PK>W=?8U=;3U`X`00M*
MF@.9!%T*VME!"TC9VD*9!)H#0]G:09H#F01"VMD``!````"L`@``)*/__RP`
M````````,````,`"```\H___Y`````!"#M!`1)V*")Z)"$*3B`B4APA"E88(
M:PK=WM73U`X`00L``!````#T`@``[*/__P0`````````:`````@#``#DH___
M+`(```!"#N`A0YV<!)Z;!$*3F@24F01#E9@$EI<$70K=WM76T]0.`$$+2)B5
M!)>6!$2:DP29E`1V"MC70=K900M6"MC70=K900M$U]C9VD&8E027E@1!FI,$
MF90$````(````'0#``"HI?__+`````!!#B"=!)X#0Y,"1M[=TPX`````;```
M`)@#``"TI?__:`$```!"#L`@0YV(!)Z'!$:5A`1$E(4$DX8$9M330=5!W=X.
M`$$.P""5A`2=B`2>AP1!U4S=W@X`00[`().&!)2%!)6$!)V(!)Z'!$P*U--"
MU4(+0=/4U4&4A023A@1!E80$`#@````(!```M*;__\0$````00Y@G0R>"T23
M"I0)1I4(E@>7!I@%F00#&P$*WMW9U]C5UM/4#@!!"P```!P```!$!```/*O_
M_W``````0PX@G02>`U4*WMT.`$$+'````&0$``",J___(`````!!#A"=`IX!
M1M[=#@`````X````A`0``(RK__\L`0```$$.0)T(G@=$DP:4!4*5!)8#6`K>
MW=76T]0.`$$+30K>W=76T]0.`$$+``"0````P`0``'RL__\$!@```$$.\`)%
MG2R>*T23*I0I0Y4HEB=#ER:8)5B:(YDD`E2<(9LB5-S;3@K:V4'=WM?8U=;3
MU`X`00M9FR*<(0)GW-M+V=I.W=[7V-76T]0.`$$.\`*3*I0IE2B6)Y<FF"69
M))HCG2R>*TB;(IPA>MO<09PAFR)!V=K;W$&:(YDD09PAFR(`,````%0%``#L
ML?__&`(```!!#E"="IX)1),(E`=$E0:6!4.7!`);"M[=U]76T]0.`$$+`#``
M``"(!0``U+/___``````00XPG0:>!423!)0#8@K>W=/4#@!!"U(*WMW3U`X`
M00L````L````O`4``#"$__\,`@```$$.8)T,G@M%DPJ4"94(E@<"6PK>W=76
MT]0.`$$+```<````[`4``&"T__]``````$$.$)T"G@%.WMT.`````#0````,
M!@``@+3__P@!````00Y`G0B>!T.3!I0%0Y4$E@-#EP*8`6,*WMW7V-76T]0.
M`$$+````-````$0&``!8M?__P`$```!!#D"=")X'0Y,&E`5#E026`T(%2`("
M8`K>W=76T]0&2`X`00L````0````?`8``."V__\,````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````0(@```````,`A`````````0``
M``````#L`@````````$`````````_`(````````!``````````8#````````
M#`````````#`&@````````T`````````/%(````````9`````````'C[`0``
M````&P`````````(`````````!H`````````@/L!```````<``````````@`
M````````]?[_;P````"8`@````````4`````````^`P````````&````````
M`(`#````````"@````````"'!`````````L`````````&``````````5````
M`````````````````P````````"8_0$```````(`````````<`4````````4
M``````````<`````````%P````````!0%0````````<`````````L!(`````
M```(`````````*`"````````"0`````````8`````````!X`````````"```
M``````#[__]O``````$```@`````_O__;P````!0$@```````/___V\`````
M`@````````#P__]O`````(`1````````^?__;P`````0````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````X!H```````#@&@```````.`:````````X!H```````#@&@``
M`````.`:````````X!H```````#@&@```````.`:````````X!H```````#@
M&@```````.`:````````X!H```````#@&@```````.`:````````X!H`````
M``#@&@```````.`:````````X!H```````#@&@```````.`:````````X!H`
M``````#@&@```````.`:````````X!H```````#@&@```````.`:````````
MX!H```````#@&@```````.`:````````X!H```````#@&@```````.`:````
M````X!H```````#@&@```````.`:````````X!H```````#@&@```````.`:
M````````X!H```````#@&@```````.`:````````X!H```````#@&@``````
M`.`:````````X!H```````#@&@```````.`:````````X!H```````#@&@``
M`````.`:````````X!H```````#@&@```````.`:````````X!H```````#@
M&@```````.`:````````X!H```````"(^P$`````````````````````````
M```43```````````````````````````````````````````````````````
M`````````````````````````````````````````````````(```@``````
M``````````#`'@``````````````````"``"```````*4$%2+G!M"@``````
M````<),```````#`4@``````````````````L%,```````!0DP```````%B3
M````````8),```````!HDP``````````````````.),```````!`DP``````
M````````````R%4```````!'0T,Z("A58G5N='4@,3(N,RXP+3-U8G5N='4Q
M*2`Q,BXS+C```"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI
M9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N
M=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`
M+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F
M<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD
M871A`"YB<W,`+F-O;6UE;G0`````````````````````````````````````
M```````````````````````````````````````````````````+`````0``
M``(`````````.`(````````X`@```````!L````````````````````!````
M````````````````$P````<````"`````````%0"````````5`(````````D
M````````````````````!````````````````````"8````'`````@``````
M``!X`@```````'@"````````(`````````````````````0`````````````
M```````T````]O__;P(`````````F`(```````"8`@```````.@`````````
M!0`````````(````````````````````/@````L````"`````````(`#````
M````@`,```````!X"0````````8````#````"``````````8`````````$8`
M```#`````@````````#X#````````/@,````````AP0`````````````````
M``$```````````````````!.````____;P(`````````@!$```````"`$0``
M`````,H`````````!0`````````"``````````(`````````6P```/[__V\"
M`````````%`2````````4!(```````!@``````````8````"````"```````
M`````````````&H````$`````@````````"P$@```````+`2````````H`(`
M```````%``````````@`````````&`````````!T````!````$(`````````
M4!4```````!0%0```````'`%````````!0```!4````(`````````!@`````
M````?@````$````&`````````,`:````````P!H````````8````````````
M````````!````````````````````'D````!````!@````````#@&@``````
M`.`:````````P`,``````````````````!````````````````````"$````
M`0````8`````````P!X```````#`'@```````'PS``````````````````!`
M````````````````````B@````$````&`````````#Q2````````/%(`````
M```4````````````````````!````````````````````)`````!`````@``
M``````!04@```````%!2````````=T$``````````````````!``````````
M``````````"8`````0````(`````````R),```````#(DP````````0!````
M```````````````$````````````````````I@````$````"`````````-"4
M````````T)0```````"0!@``````````````````"```````````````````
M`+`````.`````P````````!X^P$``````'C[````````"```````````````
M``````@`````````"`````````"\````#P````,`````````@/L!``````"`
M^P````````@````````````````````(``````````@`````````R`````8`
M```#`````````(C[`0``````B/L````````0`@````````8`````````"```
M```````0`````````-$````!`````P````````"8_0$``````)C]````````
M:`(```````````````````@`````````"`````````#6`````0````,`````
M```````"``````````$``````(@````````````````````(````````````
M````````W`````@````#`````````(@``@``````B``!```````H````````
M````````````"````````````````````.$````!````,```````````````
M`````(@``0``````)0````````````````````$``````````0`````````!
M`````P````````````````````````"M``$``````.H`````````````````
2```!````````````````````
